@@ -3,6 +3,7 @@
 import json
 import tornado.ioloop
 import tornado.web
+import tornado.escape
 from .wsdl import Soap
 
 class MainHandler(tornado.web.RequestHandler):
@@ -15,12 +16,13 @@ class MainHandler(tornado.web.RequestHandler):
     def get(self):
         if 'wsdl' in self.request.arguments:
             with open('./wsdl.xml') as f:
-                self.write(f.read())
-                self.set_header( 'Content-Type', 'text/xml' )
-                self.finish()
+                wsdl = f.read()
+                self.set_header( 'Content-Type', 'application/xml charset=utf-8' )
+                self.finish(wsdl)
         else:
-            self.write(json.dumps(MainHandler.config, indent=4))
-            self.finish()
+            config = json.dumps(MainHandler.config, indent=4)
+            self.set_header( 'Content-Type', 'application/json charset=utf-8' )
+            self.finish(config)
 
     def post(self):
         url = self.request.path[1:]
@@ -33,7 +35,8 @@ class MainHandler(tornado.web.RequestHandler):
             return self.write(f"invalid method {port}")
         file_path = ports[port]
         with open(file_path, 'r') as f:
-            self.write(f.read())
+            self.set_header( 'Content-Type', 'application/xml charset=utf-8' )
+            self.finish(f.read())
 
 
 def make_app():
